#!/bin/bash

echo "Starting custom icon installation step"

# Only allow run in Meson
if [ -z $MESON_INSTALL_PREFIX ]; then
    echo 'This script should only be run from Meson.'
    exit 1
fi

PACKAGE_ID="PACKAGE_ID"
ICON_SIZES=()

# Get Arguments
while [[ $# -gt 1 ]]
do
key="$1"

case $key in
    -n|--name)
    PACKAGE_ID="$2"
    shift # past argument
    ;;
    -s|--size)
    ICON_SIZES+=("$2")
    shift # past argument
    ;;
    *)
            # unknown option
    ;;
esac
shift
done

if [ ${#ICON_SIZES[@]} -eq 0 ]; then
	ICON_SIZES=(16 22 24 32 48 256 512)
fi

cd "${MESON_SOURCE_ROOT}/data"

for i in "${ICON_SIZES[@]}"
do
    mkdir -p "${MESON_BUILD_ROOT}/data/icons/hicolor/${i}x${i}/apps/"

    inkscape \
        -z \
        -e "${MESON_BUILD_ROOT}/data/icons/hicolor/${i}x${i}/apps/${PACKAGE_ID}.png" \
        -w $i \
        -h $i \
        "${MESON_SOURCE_ROOT}/data/PACKAGE_ID.svg"
done

echo "Finished custom install step"

